==> snipe-it-5.1.8.zip: snipe-it-5.1.8/resources/lang/it/help.php <==
<?php

return array(

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    "more_info_title" => "Ulteriori Informazioni",

    "audit_help" => "Selezionando questa casella verrà modificato l'asset per riflettere la nuova località, altrimenti verrà semplicemente menzionato nel registro di audit.<br><br>Se l'asset è già assegnato, non cambierà la località dell'utente, dell'asset o la località a cui è assegnato.",

    'assets' => 'Assets sono elementi tracciati con il numero di serie o il tag. Tendono ad essere elementi di valore più elevato, ove è importante identificare un elemento specifico.',

    'categories' => 'Le categorie ti aiutano ad organizzare i tuoi elementi. Alcuni esempi possono essere &quot;Computer Fissi&quot;, &quot;Portatili&quot;, &quot;Cellulari&quot;, &quot;Tablet&quot; e molto altro ancora, però puoi creare ed assegnare qualsiasi categoria più appropriata.',

    'accessories' => 'Gli accessori sono elementi, sprovvisti di numero di serie o per i quali non è necessario un tracciamento individuale, che puoi assegnare agli utenti. Ad esempio mouse e tastiere.',

    'companies'     => 'Le aziende possono essere utilizzate come un campo di identificazione semplice oppure per limitare la visibilità degli asset, degli utenti ecc., se il supporto aziendale completo è abilitato nelle impostazioni di amministratore.',

    'components'    => 'I componenti sono parti di un asset, ad esempio HDD, RAM, ecc.',

    'consumables'   => 'I materiali di consumo sono qualsiasi cosa acquistata che verrà utilizzata nel tempo. Per esempio l\'inchiostro per stampanti o la carta per fotocopiatrici.',

    'depreciations' => 'È possibile impostare gli ammortamenti, per ammortizzare un asset secondo il criterio di calcolo a quote costanti.',



);

==> snipe-it-5.4.3.zip: snipe-it-5.4.3/resources/lang/it/help.php <==
<?php

return [

    /*
    |--------------------------------------------------------------------------
    | Password Reminder Language Lines
    |--------------------------------------------------------------------------
    |
    | The following language lines are the default lines which match reasons
    | that are given by the password broker for a password update attempt
    | has failed, such as for an invalid token or invalid new password.
    |
    */

    'more_info_title' => 'Ulteriori Informazioni',

    'audit_help' => 'Selezionando questa casella verrà modificato l\'asset per riflettere la nuova località, altrimenti verrà semplicemente menzionato nel registro di audit.<br><br>Se l\'asset è già assegnato, non cambierà la località dell\'utente, dell\'asset o la località a cui è assegnato.',

    'assets' => 'Assets sono elementi tracciati con il numero di serie o il tag. Tendono ad essere elementi di valore più elevato, ove è importante identificare un elemento specifico.',

    'categories' => 'Le categorie ti aiutano ad organizzare i tuoi elementi. Alcuni esempi possono essere &quot;Computer Fissi&quot;, &quot;Portatili&quot;, &quot;Cellulari&quot;, &quot;Tablet&quot; e molto altro ancora, però puoi creare ed assegnare qualsiasi categoria più appropriata.',

    'accessories' => 'Gli accessori sono elementi, sprovvisti di numero di serie o per i quali non è necessario un tracciamento individuale, che puoi assegnare agli utenti. Ad esempio mouse e tastiere.',

    'companies'     => 'Le aziende possono essere utilizzate come un campo di identificazione semplice oppure per limitare la visibilità degli asset, degli utenti ecc., se il supporto aziendale completo è abilitato nelle impostazioni di amministratore.',

    'components'    => 'I componenti sono parti di un asset, ad esempio HDD, RAM, ecc.',

    'consumables'   => 'I materiali di consumo sono qualsiasi cosa acquistata che verrà utilizzata nel tempo. Per esempio l\'inchiostro per stampanti o la carta per fotocopiatrici.',

    'depreciations' => 'È possibile impostare gli ammortamenti, per ammortizzare un asset secondo il criterio di calcolo a quote costanti.',

];
